// ------------------------------------------------------------
// A Loitd Utilities Library for JavaScript Project
// URL: github.com/loitd/lutilsjs
// ------------------------------------------------------------
// You cannot have a default export and give it a name ("default" is already the name of the export)
// const hello = () => console.log("say hello"); export default hello;
// or
// export const print = (message) => {}

// Using node-fetch lib at: https://www.npmjs.com/package/node-fetch
const fetch = require('node-fetch');

exports.print = (message) => {
    console.log(message);
};

// https://www.metaweather.com/api/#locationsearch
// Returns WOEID
// A WOEID (Where On Earth IDentifier) is a unique 32-bit reference identifier, originally defined by GeoPlanet and now assigned by Yahoo!
// All map: https://www.metaweather.com/map/
// Keep in mind that in order to call a function using the await keyword, it must be within the async function
async function getLocationId(location){
    try{
        location = location.trim();
        const url = await encodeURI("https://www.metaweather.com/api/location/search/?query=" + location);
        // The data we are going to send in our request
        let body = { query: location, };
        // The parameters we are gonna pass to the fetch function
        // body: body, // a GET/HEAD can not have a body
        const fetchOptions = { method: 'GET', headers: new fetch.Headers(), };
        // Fetch & Handle response you get from the server
        const resp = await fetch(url, fetchOptions);
        const data = await resp.json(); //convert to json first
        // handling data got from api
        // console.log(data[0]);
        if (typeof data[0] != 'undefined'){
            let woeid = await data[0].woeid;
            return {result:true, woeid};
        } else {
            throw "Location not found!";
        }
    } catch (e) {
        //if any errors
        // console.log(e);
        return {result:false};
    }
};

// 
async function getWeatherFromWoeid(woeid){
    try{
        const url = await encodeURI("https://www.metaweather.com/api/location/" + woeid);
        // The data we are going to send in our request
        let body = { query: woeid, };
        // The parameters we are gonna pass to the fetch function
        const fetchOptions = { method: 'GET', headers: new fetch.Headers(),};
        // Fetch & Handle response you get from the server
        const resp = await fetch(url, fetchOptions);
        const data = await resp.json(); //convert to json first
        // console.log(data);
        let title = data.title;
        let parent = data.parent.title;
        let {weather_state_name, weather_state_abbr, applicable_date, min_temp, max_temp, the_temp} = data.consolidated_weather[0];
        min_temp = min_temp.toFixed(2);
        max_temp = max_temp.toFixed(2);
        the_temp = the_temp.toFixed(2);
        const retval = {result:true,title, parent, weather_state_name, weather_state_abbr, applicable_date, min_temp, max_temp, the_temp};
        // console.log(retval);
        return retval;
    } catch(e){
        console.log(e);
        return {result: false};
    }
};

async function getWeatherFromLocation(location){
    let {result, woeid} = await getLocationId(location);
    if (result){
        let wea = await getWeatherFromWoeid(woeid);
        console.log(wea);
        return wea;
    } else {
        return {result:false};
    }    
}

// async function fetchData() {
//     try {
//       const data = await Promise.all([
//         fetch(`${apiUrl}/users`),
//         fetch(`${apiUrl}/companies`),
//         fetch(`${apiUrl}/articles`)
//       ]);
//       console.log('users, companies and articles are fetched in parallel');
//     } catch (e) {
//       console.error(e);
//     }
// }

// getLocationId('Hanoi');

exports.getLocationId = getLocationId;
exports.getWeatherFromWoeid = getWeatherFromWoeid;
exports.getWeatherFromLocation = getWeatherFromLocation;